@@ -672,6 +672,18 @@
 #define hipblasDgeqrfFortran hipblasDgeqrf
 #define hipblasCgeqrfFortran hipblasCgeqrf
 #define hipblasZgeqrfFortran hipblasZgeqrf
+#define hipblasSgelsFortran hipblasSgels
+#define hipblasDgelsFortran hipblasDgels
+#define hipblasCgelsFortran hipblasCgels
+#define hipblasZgelsFortran hipblasZgels
+#define hipblasSgelsBatchedFortran hipblasSgelsBatched
+#define hipblasDgelsBatchedFortran hipblasDgelsBatched
+#define hipblasCgelsBatchedFortran hipblasCgelsBatched
+#define hipblasZgelsBatchedFortran hipblasZgelsBatched
+#define hipblasSgelsStridedBatchedFortran hipblasSgelsStridedBatched
+#define hipblasDgelsStridedBatchedFortran hipblasDgelsStridedBatched
+#define hipblasCgelsStridedBatchedFortran hipblasCgelsStridedBatched
+#define hipblasZgelsStridedBatchedFortran hipblasZgelsStridedBatched
 #define hipblasSgeqrfBatchedFortran hipblasSgeqrfBatched
 #define hipblasDgeqrfBatchedFortran hipblasDgeqrfBatched
 #define hipblasCgeqrfBatchedFortran hipblasCgeqrfBatched
