@@ -33,10 +33,28 @@
 
 /* ============================================================================================ */
 
-template <typename Ta, typename Tb = Ta, typename Tc = Tb, typename Tex = Tc>
-hipblasStatus_t testing_gemm_strided_batched_ex_template(const Arguments& argus)
+using hipblasGemmStridedBatchedExModel = ArgumentModel<e_transA,
+                                                       e_transB,
+                                                       e_M,
+                                                       e_N,
+                                                       e_K,
+                                                       e_alpha,
+                                                       e_lda,
+                                                       e_ldb,
+                                                       e_beta,
+                                                       e_ldc,
+                                                       e_batch_count>;
+// strides not logged
+
+inline void testname_gemm_strided_batched_ex(const Arguments& arg, std::string& name)
 {
-    bool FORTRAN = argus.fortran;
+    hipblasGemmStridedBatchedExModel{}.test_name(arg, name);
+}
+
+template <typename Ta, typename Tb = Ta, typename Tc = Tb, typename Tex = Tc>
+inline hipblasStatus_t testing_gemm_strided_batched_ex_template(const Arguments& arg)
+{
+    bool FORTRAN = arg.fortran;
     auto hipblasGemmStridedBatchedExFn
         = FORTRAN ? hipblasGemmStridedBatchedExFortran : hipblasGemmStridedBatchedExFortran;
 
@@ -44,30 +62,28 @@ hipblasStatus_t testing_gemm_strided_batched_ex_template(const Arguments& argus)
     uint32_t          solution_index = 0;
     uint32_t          flags          = 0;
 
-    hipblasOperation_t transA = char2hipblas_operation(argus.transA_option);
-    hipblasOperation_t transB = char2hipblas_operation(argus.transB_option);
+    hipblasOperation_t transA = char2hipblas_operation(arg.transA);
+    hipblasOperation_t transB = char2hipblas_operation(arg.transB);
+    int                M      = arg.M;
+    int                N      = arg.N;
+    int                K      = arg.K;
+    int                lda    = arg.lda;
+    int                ldb    = arg.ldb;
+    int                ldc    = arg.ldc;
 
-    int M = argus.M;
-    int N = argus.N;
-    int K = argus.K;
+    hipblasDatatype_t a_type       = arg.a_type;
+    hipblasDatatype_t b_type       = arg.b_type;
+    hipblasDatatype_t c_type       = arg.c_type;
+    hipblasDatatype_t compute_type = arg.compute_type;
 
-    int lda = argus.lda;
-    int ldb = argus.ldb;
-    int ldc = argus.ldc;
+    int batch_count = arg.batch_count;
 
-    hipblasDatatype_t a_type       = argus.a_type;
-    hipblasDatatype_t b_type       = argus.b_type;
-    hipblasDatatype_t c_type       = argus.c_type;
-    hipblasDatatype_t compute_type = argus.compute_type;
+    int norm_check = arg.norm_check;
+    int unit_check = arg.unit_check;
+    int timing     = arg.timing;
 
-    int batch_count = argus.batch_count;
-
-    int norm_check = argus.norm_check;
-    int unit_check = argus.unit_check;
-    int timing     = argus.timing;
-
-    Tex h_alpha_Tc = argus.get_alpha<Tex>();
-    Tex h_beta_Tc  = argus.get_beta<Tex>();
+    Tex h_alpha_Tc = arg.get_alpha<Tex>();
+    Tex h_beta_Tc  = arg.get_beta<Tex>();
 
     int A_row = transA == HIPBLAS_OP_N ? M : K;
     int A_col = transA == HIPBLAS_OP_N ? K : M;
@@ -102,7 +118,7 @@ hipblasStatus_t testing_gemm_strided_batched_ex_template(const Arguments& argus)
     }
 
     double             gpu_time_used, hipblas_error_host, hipblas_error_device;
-    hipblasLocalHandle handle(argus);
+    hipblasLocalHandle handle(arg);
 
     // Naming: dX is in GPU (device) memory. hK is in CPU (host) memory
     host_vector<Ta> hA(size_A);
@@ -113,11 +129,11 @@ hipblasStatus_t testing_gemm_strided_batched_ex_template(const Arguments& argus)
 
     // Initial Data on CPU
     hipblas_init_matrix(
-        hA, argus, A_row, A_col, lda, stride_A, batch_count, hipblas_client_alpha_sets_nan, true);
+        hA, arg, A_row, A_col, lda, stride_A, batch_count, hipblas_client_alpha_sets_nan, true);
     hipblas_init_matrix(
-        hB, argus, B_row, B_col, ldb, stride_B, batch_count, hipblas_client_alpha_sets_nan);
+        hB, arg, B_row, B_col, ldb, stride_B, batch_count, hipblas_client_alpha_sets_nan);
     hipblas_init_matrix(
-        hC_host, argus, M, N, ldc, stride_C, batch_count, hipblas_client_beta_sets_nan);
+        hC_host, arg, M, N, ldc, stride_C, batch_count, hipblas_client_beta_sets_nan);
     hC_gold = hC_device = hC_host;
 
     // copy data from CPU to device
@@ -125,7 +141,7 @@ hipblasStatus_t testing_gemm_strided_batched_ex_template(const Arguments& argus)
     CHECK_HIP_ERROR(hipMemcpy(dA, hA, sizeof(Ta) * size_A, hipMemcpyHostToDevice));
     CHECK_HIP_ERROR(hipMemcpy(dB, hB, sizeof(Tb) * size_B, hipMemcpyHostToDevice));
 #else
-    if(std::is_same<Ta, int8_t>{} && transA == HIPBLAS_OP_N && layout_pack_int8())
+    if(std::is_same<Ta, int8_t>{} && transA == HIPBLAS_OP_N && layout_pack_int8(handle))
     {
         host_vector<Ta> hA_packed(hA);
         hipblas_packInt8(hA_packed, M, K, lda, batch_count, stride_A);
@@ -136,7 +152,7 @@ hipblasStatus_t testing_gemm_strided_batched_ex_template(const Arguments& argus)
         CHECK_HIP_ERROR(hipMemcpy(dA, hA, sizeof(Ta) * size_A, hipMemcpyHostToDevice));
     }
 
-    if(std::is_same<Tb, int8_t>{} && transB != HIPBLAS_OP_N && layout_pack_int8())
+    if(std::is_same<Tb, int8_t>{} && transB != HIPBLAS_OP_N && layout_pack_int8(handle))
     {
         host_vector<Tb> hB_packed(hB);
         hipblas_packInt8(hB_packed, N, K, ldb, batch_count, stride_B);
@@ -228,12 +244,25 @@ hipblasStatus_t testing_gemm_strided_batched_ex_template(const Arguments& argus)
                                     ldc);
         }
 
-        if(argus.unit_check)
+        if(unit_check)
         {
-            unit_check_general<Tc>(M, N, batch_count, ldc, stride_C, hC_gold, hC_host);
-            unit_check_general<Tc>(M, N, batch_count, ldc, stride_C, hC_gold, hC_device);
+            // check for float16/bfloat16 input
+            if((getArchMajor() == 11)
+               && ((std::is_same<Tex, float>{} && std::is_same<Ta, hipblasBfloat16>{})
+                   || (std::is_same<Tex, float>{} && std::is_same<Ta, hipblasHalf>{})
+                   || (std::is_same<Tex, hipblasHalf>{} && std::is_same<Ta, hipblasHalf>{})))
+            {
+                const double tol = K * sum_error_tolerance_for_gfx11<Tex, Ta, Tc>;
+                near_check_general<Tc>(M, N, batch_count, ldc, stride_C, hC_gold, hC_host, tol);
+                near_check_general<Tc>(M, N, batch_count, ldc, stride_C, hC_gold, hC_device, tol);
+            }
+            else
+            {
+                unit_check_general<Tc>(M, N, batch_count, ldc, stride_C, hC_gold, hC_host);
+                unit_check_general<Tc>(M, N, batch_count, ldc, stride_C, hC_gold, hC_device);
+            }
         }
-        if(argus.norm_check)
+        if(arg.norm_check)
         {
             hipblas_error_host
                 = norm_check_general<Tc>('F', M, N, ldc, stride_C, hC_gold, hC_host, batch_count);
@@ -248,10 +277,10 @@ hipblasStatus_t testing_gemm_strided_batched_ex_template(const Arguments& argus)
         CHECK_HIPBLAS_ERROR(hipblasGetStream(handle, &stream));
         CHECK_HIPBLAS_ERROR(hipblasSetPointerMode(handle, HIPBLAS_POINTER_MODE_HOST));
 
-        int runs = argus.cold_iters + argus.iters;
+        int runs = arg.cold_iters + arg.iters;
         for(int iter = 0; iter < runs; iter++)
         {
-            if(iter == argus.cold_iters)
+            if(iter == arg.cold_iters)
                 gpu_time_used = get_time_us_sync(stream);
 
             CHECK_HIPBLAS_ERROR(hipblasGemmStridedBatchedExFn(handle,
@@ -280,40 +309,31 @@ hipblasStatus_t testing_gemm_strided_batched_ex_template(const Arguments& argus)
         }
         gpu_time_used = get_time_us_sync(stream) - gpu_time_used;
 
-        ArgumentModel<e_transA_option,
-                      e_transB_option,
-                      e_M,
-                      e_N,
-                      e_K,
-                      e_lda,
-                      e_ldb,
-                      e_ldc,
-                      e_batch_count>{}
-            .log_args<Tc>(std::cout,
-                          argus,
-                          gpu_time_used,
-                          gemm_gflop_count<Tex>(M, N, K),
-                          gemm_gbyte_count<Tex>(M, N, K),
-                          hipblas_error_host,
-                          hipblas_error_device);
+        hipblasGemmStridedBatchedExModel{}.log_args<Tc>(std::cout,
+                                                        arg,
+                                                        gpu_time_used,
+                                                        gemm_gflop_count<Tex>(M, N, K),
+                                                        gemm_gbyte_count<Tex>(M, N, K),
+                                                        hipblas_error_host,
+                                                        hipblas_error_device);
     }
 
     return HIPBLAS_STATUS_SUCCESS;
 }
 
-hipblasStatus_t testing_gemm_strided_batched_ex(const Arguments& argus)
+inline hipblasStatus_t testing_gemm_strided_batched_ex(const Arguments& arg)
 {
-    hipblasDatatype_t a_type       = argus.a_type;
-    hipblasDatatype_t b_type       = argus.b_type;
-    hipblasDatatype_t c_type       = argus.c_type;
-    hipblasDatatype_t compute_type = argus.compute_type;
+    hipblasDatatype_t a_type       = arg.a_type;
+    hipblasDatatype_t b_type       = arg.b_type;
+    hipblasDatatype_t c_type       = arg.c_type;
+    hipblasDatatype_t compute_type = arg.compute_type;
 
     hipblasStatus_t status = HIPBLAS_STATUS_SUCCESS;
 
     if(a_type == HIPBLAS_R_16F && b_type == HIPBLAS_R_16F && c_type == HIPBLAS_R_16F
        && c_type == HIPBLAS_R_16F && compute_type == HIPBLAS_R_16F)
     {
-        status = testing_gemm_strided_batched_ex_template<hipblasHalf>(argus);
+        status = testing_gemm_strided_batched_ex_template<hipblasHalf>(arg);
     }
     else if(a_type == HIPBLAS_R_16F && b_type == HIPBLAS_R_16F && c_type == HIPBLAS_R_16F
             && c_type == HIPBLAS_R_16F && compute_type == HIPBLAS_R_32F)
@@ -321,7 +341,7 @@ hipblasStatus_t testing_gemm_strided_batched_ex(const Arguments& argus)
         status = testing_gemm_strided_batched_ex_template<hipblasHalf,
                                                           hipblasHalf,
                                                           hipblasHalf,
-                                                          float>(argus);
+                                                          float>(arg);
     }
     else if(a_type == HIPBLAS_R_16B && b_type == HIPBLAS_R_16B && c_type == HIPBLAS_R_16B
             && c_type == HIPBLAS_R_16B && compute_type == HIPBLAS_R_32F)
@@ -329,32 +349,32 @@ hipblasStatus_t testing_gemm_strided_batched_ex(const Arguments& argus)
         status = testing_gemm_strided_batched_ex_template<hipblasBfloat16,
                                                           hipblasBfloat16,
                                                           hipblasBfloat16,
-                                                          float>(argus);
+                                                          float>(arg);
     }
     else if(a_type == HIPBLAS_R_32F && b_type == HIPBLAS_R_32F && c_type == HIPBLAS_R_32F
             && c_type == HIPBLAS_R_32F && compute_type == HIPBLAS_R_32F)
     {
-        status = testing_gemm_strided_batched_ex_template<float>(argus);
+        status = testing_gemm_strided_batched_ex_template<float>(arg);
     }
     else if(a_type == HIPBLAS_R_64F && b_type == HIPBLAS_R_64F && c_type == HIPBLAS_R_64F
             && c_type == HIPBLAS_R_64F && compute_type == HIPBLAS_R_64F)
     {
-        status = testing_gemm_strided_batched_ex_template<double>(argus);
+        status = testing_gemm_strided_batched_ex_template<double>(arg);
     }
     else if(a_type == HIPBLAS_C_32F && b_type == HIPBLAS_C_32F && c_type == HIPBLAS_C_32F
             && c_type == HIPBLAS_C_32F && compute_type == HIPBLAS_C_32F)
     {
-        status = testing_gemm_strided_batched_ex_template<hipblasComplex>(argus);
+        status = testing_gemm_strided_batched_ex_template<hipblasComplex>(arg);
     }
     else if(a_type == HIPBLAS_C_64F && b_type == HIPBLAS_C_64F && c_type == HIPBLAS_C_64F
             && c_type == HIPBLAS_C_64F && compute_type == HIPBLAS_C_64F)
     {
-        status = testing_gemm_strided_batched_ex_template<hipblasDoubleComplex>(argus);
+        status = testing_gemm_strided_batched_ex_template<hipblasDoubleComplex>(arg);
     }
     else if(a_type == HIPBLAS_R_8I && b_type == HIPBLAS_R_8I && c_type == HIPBLAS_R_32I
             && c_type == HIPBLAS_R_32I && compute_type == HIPBLAS_R_32I)
     {
-        status = testing_gemm_strided_batched_ex_template<int8_t, int8_t, int32_t, int32_t>(argus);
+        status = testing_gemm_strided_batched_ex_template<int8_t, int8_t, int32_t, int32_t>(arg);
     }
     else
     {
